from src.backtest.bollinger_bands import run_bollinger_backtest, start_bollinger_backtest_service
from src.backtest.dual_moving_average import run_sma_backtest, start_sma_backtest_service
from src.backtest.reverse_dual_ma_strategy import start_reverse_SMA_backtest_service
from src.backtest.rsi_strategy import start_rsi_backtest_service
from src.backtest.until import data_check


async def start_backtest_service(field_list: list,
                                 stock_list: list,
                                 period: str = '1d',
                                 start_time: str = '',
                                 end_time: str = '',
                                 count: int = -1,
                                 dividend_type: str = 'none',
                                 fill_data: bool = True,
                                 data_dir: str = '',
                                 ma_type: str = 'SMA',
                                 short_window: int = 50,
                                 long_window: int = 200,
                                 bollingerMA: int = 200,
                                 std_dev: int = 200,
                                 overbought: int = 70,
                                 oversold: int = 30,
                                 signal_window: int = 9):
    # 数据检查
    await data_check(field_list=field_list,
                     stock_list=stock_list,
                     period=period,
                     start_time=start_time,
                     end_time=end_time,
                     count=count,
                     dividend_type=dividend_type,
                     fill_data=fill_data,
                     data_dir=data_dir)

    # 策略映射
    strategies = {
        'SMA': start_sma_backtest_service,
        'Bollinger': start_bollinger_backtest_service,
        'RSI': start_rsi_backtest_service,
        'RESMA': start_reverse_SMA_backtest_service,
        'MACD': start_rsi_backtest_service
    }

    # 通用参数
    base_params = {
        'field_list': field_list,
        'stock_list': stock_list,
        'period': period,
        'start_time': start_time,
        'end_time': end_time,
        'count': count,
        'dividend_type': dividend_type,
        'fill_data': fill_data,
        'data_dir': data_dir,
    }

    # 特定策略参数
    strategy_params = {
        'SMA': {'short_window': short_window, 'long_window': long_window},
        'Bollinger': {'bollingerMA': bollingerMA, 'std_dev': std_dev},
        'RSI': {'short_window': short_window, 'long_window': long_window, 'overbought': overbought,
                'oversold': oversold},
        'RESMA': {'short_window': short_window, 'long_window': long_window},
        'MACD': {'short_window': short_window, 'long_window': signal_window}
    }

    # 选择策略并执行
    strategy_func = strategies.get(ma_type)
    if strategy_func:
        result = await strategy_func(**base_params, **strategy_params[ma_type])
        return result
    else:
        return None
