import sentry_sdk
import uvicorn
from fastapi import FastAPI
from starlette.middleware.cors import CORSMiddleware

from src.exceptions import register_exception_handler
from src.tortoises import register_tortoise_orm
from src.xtdata.router import router as xtdata_router
from src.backtest.router import router as backtest_router

from xtquant import xtdata
from src.settings.config import app_configs, settings




app = FastAPI(**app_configs)

register_tortoise_orm(app)

register_exception_handler(app)

app.include_router(xtdata_router, prefix="/getwancedata", tags=["盘口数据"])
app.include_router(backtest_router, prefix="/backtest", tags=["盘口数据"])


if settings.ENVIRONMENT.is_deployed:
    sentry_sdk.init(
        dsn=settings.SENTRY_DSN,
        environment=settings.ENVIRONMENT,
    )

app.add_middleware(
    CORSMiddleware,
    allow_origins=settings.CORS_ORIGINS,
    allow_origin_regex=settings.CORS_ORIGINS_REGEX,
    allow_credentials=True,
    allow_methods=("GET", "POST", "PUT", "PATCH", "DELETE", "OPTIONS"),
    allow_headers=settings.CORS_HEADERS,
)




@app.get("/")
async def root():
    return {"message": "Hello, FastAPI!"}



if __name__ == "__main__":
    uvicorn.run('src.main:app', host="0.0.0.0", port=8011, reload=True)
